@@ -7,12 +7,13 @@
  ****************************************************************************/
 
 /*
- * This program is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  * 
- * This program is distributed in the hope that it will be useful,
+ * Brasero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
@@ -34,6 +35,7 @@
 
 #include "brasero-file-node.h"
 #include "brasero-utils.h"
+#include "brasero-io.h"
 
 BraseroFileNode *
 brasero_file_node_root_new (void)
@@ -455,6 +457,9 @@ brasero_file_node_nth_child (BraseroFileNode *parent,
 	BraseroFileNode *peers;
 	guint pos;
 
+	if (!parent)
+		return NULL;
+
 	peers = BRASERO_FILE_NODE_CHILDREN (parent);
 	for (pos = 0; pos < nth && peers; pos ++)
 		peers = peers->next;
@@ -468,6 +473,9 @@ brasero_file_node_get_n_children (const BraseroFileNode *node)
 	BraseroFileNode *children;
 	guint num = 0;
 
+	if (!node)
+		return 0;
+
 	for (children = BRASERO_FILE_NODE_CHILDREN (node); children; children = children->next)
 		num ++;
 
@@ -481,6 +489,9 @@ brasero_file_node_get_pos_as_child (BraseroFileNode *node)
 	BraseroFileNode *peers;
 	guint pos = 0;
 
+	if (!node)
+		return 0;
+
 	parent = node->parent;
 	for (peers = BRASERO_FILE_NODE_CHILDREN (parent); peers; peers = peers->next) {
 		if (peers == node)
@@ -583,7 +594,7 @@ brasero_file_node_validate_utf8_name (const gchar *name)
 		return NULL;
 
 	if (g_utf8_validate (name, -1, &invalid))
-		return g_markup_escape_text (name, -1);
+		return NULL;
 
 	retval = g_strdup (name);
 	ptr = retval + (invalid - name);
@@ -596,10 +607,6 @@ brasero_file_node_validate_utf8_name (const gchar *name)
 		ptr ++;
 	}
 
-	ptr = retval;
-	retval = g_markup_escape_text (retval, -1);
-	g_free (ptr);
-
 	return retval;
 }
 
@@ -655,7 +662,7 @@ brasero_file_node_ungraft (BraseroFileNode *node)
 	/* Remove it from the URINode list of grafts */
 	graft->node->nodes = g_slist_remove (graft->node->nodes, node);
 
-	/* The name must be exactly the one of the URI*/
+	/* The name must be exactly the one of the URI */
 	node->is_grafted = FALSE;
 	node->union1.name = graft->name;
 
@@ -687,16 +694,16 @@ brasero_file_node_add (BraseroFileNode *parent,
 		       BraseroFileNode *node,
 		       GCompareFunc sort_func)
 {
+	BraseroFileTreeStats *stats;
+	guint depth = 0;
+
 	parent->union2.children = brasero_file_node_insert (BRASERO_FILE_NODE_CHILDREN (parent),
 							    node,
 							    sort_func,
 							    NULL);
-
 	node->parent = parent;
 	if (!node->is_imported) {
-		BraseroFileTreeStats *stats;
-		guint depth = 0;
-
+		/* NOTE: parent will be changed afterwards !!! */
 		if (!node->is_grafted) {
 			/* propagate the size change*/
 			for (; parent && !parent->is_root; parent = parent->parent) {
@@ -705,16 +712,19 @@ brasero_file_node_add (BraseroFileNode *parent,
 					break;
 			}
 		}
-
-		stats = brasero_file_node_get_tree_stats (parent, &depth);
-		if (node->is_file) {
-			/* only count files */
-			stats->children ++;
-		}
-
-		if (depth > 6)
-			node->is_deep = TRUE;
 	}
+
+	/* even imported should be included */
+	stats = brasero_file_node_get_tree_stats (node->parent, &depth);
+	if (node->is_file) {
+		if (depth < 6)
+			return;
+	}
+	else if (depth < 5)
+		return;
+
+	stats->num_deep ++;
+	node->is_deep = TRUE;
 }
 
 void
@@ -727,6 +737,15 @@ brasero_file_node_set_from_info (BraseroFileNode *node,
 	 * creation of a graft). If someone wants to set a new name,
 	 * then rename_node is the function. */
 
+	/* update the stats since a file could have been added to the tree but
+	 * at this point we didn't know what it was (a file or a directory).
+	 * Only do this if it wasn't a file before. */
+	if (!node->is_file
+	&& (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY)) {
+		/* only count files */
+		stats->children ++;
+	}
+
 	/* update :
 	 * - the mime type
 	 * - the size (and possibly the one of his parent)
@@ -753,12 +772,12 @@ brasero_file_node_set_from_info (BraseroFileNode *node,
 			node->union2.mime = brasero_utils_register_string (mime);
 		}
 
-		sectors = BRASERO_SIZE_TO_SECTORS (g_file_info_get_size (info), 2048);
+		sectors = BRASERO_BYTES_TO_SECTORS (g_file_info_get_size (info), 2048);
 
 		if (sectors > BRASERO_FILE_2G_LIMIT && BRASERO_FILE_NODE_SECTORS (node) <= BRASERO_FILE_2G_LIMIT)
-			stats->num_2Gio ++;
+			stats->num_2GiB ++;
 		else if (sectors <= BRASERO_FILE_2G_LIMIT && BRASERO_FILE_NODE_SECTORS (node) > BRASERO_FILE_2G_LIMIT)
-			stats->num_2Gio --;
+			stats->num_2GiB --;
 
 		/* The node isn't grafted and it's a file. So we must propagate
 		 * its size up to the parent graft node. */
@@ -779,7 +798,7 @@ brasero_file_node_set_from_info (BraseroFileNode *node,
 gchar *
 brasero_file_node_get_uri_name (const gchar *uri)
 {
-	gchar *unescaped_name;
+	gchar *utf8_name;
 	GFile *vfs_uri;
 	gchar *name;
 
@@ -789,19 +808,18 @@ brasero_file_node_get_uri_name (const gchar *uri)
 	name = g_file_get_basename (vfs_uri);
 	g_object_unref (vfs_uri);
 
-	unescaped_name = g_uri_unescape_string (name, NULL);
-	g_free (name);
+	/* NOTE and reminder names are already unescaped; the following is not
+	 * needed: unescaped_name = g_uri_unescape_string (name, NULL); */
 
 	/* NOTE: a graft should be added for non utf8 name since we
 	 * modify them; in fact we use this function only in the next
 	 * one which creates only grafted nodes. */
-	name = brasero_file_node_validate_utf8_name (unescaped_name);
-	if (name) {
-		g_free (unescaped_name);
-		return name;
+	utf8_name = brasero_file_node_validate_utf8_name (name);
+	if (utf8_name) {
+		g_free (name);
+		return utf8_name;
 	}
-
-	return unescaped_name;
+	return name;
 }
 
 BraseroFileNode *
@@ -841,7 +859,7 @@ brasero_file_node_new_from_info (GFileInfo *info,
 }
 
 BraseroFileNode *
-brasero_file_node_new_imported_session_file (BraseroVolFile *file,
+brasero_file_node_new_imported_session_file (GFileInfo *info,
 					     BraseroFileNode *parent,
 					     GCompareFunc sort_func)
 {
@@ -849,12 +867,16 @@ brasero_file_node_new_imported_session_file (BraseroVolFile *file,
 
 	/* Create the node information */
 	node = g_new0 (BraseroFileNode, 1);
-	node->union1.name = g_strdup (BRASERO_VOLUME_FILE_NAME (file));
-	node->is_file = (file->isdir == FALSE);
+	node->union1.name = g_strdup (g_file_info_get_name (info));
+	node->is_file = (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY);
 	node->is_imported = TRUE;
 
-	if (node->is_file)
-		node->union3.sectors = BRASERO_SIZE_TO_SECTORS (BRASERO_VOLUME_FILE_SIZE (file), 2048);
+	if (!node->is_file) {
+		node->is_fake = TRUE;
+		node->union3.imported_address = g_file_info_get_attribute_int64 (info, BRASERO_IO_DIR_CONTENTS_ADDR);
+	}
+	else
+		node->union3.sectors = BRASERO_BYTES_TO_SECTORS (g_file_info_get_size (info), 2048);
 
 	/* Add it (we must add a graft) */
 	brasero_file_node_add (parent, node, sort_func);
@@ -949,14 +971,11 @@ void
 brasero_file_node_move_from (BraseroFileNode *node,
 			     BraseroFileTreeStats *stats)
 {
-	gboolean was_deep;
-
 	/* NOTE: for the time being no backend supports moving imported files */
 	if (node->is_imported)
 		return;
 
-	was_deep = (brasero_file_node_get_depth (node) > 6);
-	if (was_deep)
+	if (node->is_deep)
 		stats->num_deep --;
 
 	brasero_file_node_unlink (node);
@@ -968,7 +987,7 @@ brasero_file_node_move_to (BraseroFileNode *node,
 			   GCompareFunc sort_func)
 {
 	BraseroFileTreeStats *stats;
-	guint depth;
+	guint depth = 0;
 
 	/* NOTE: for the time being no backend supports moving imported files */
 	if (node->is_imported)
@@ -994,11 +1013,16 @@ brasero_file_node_move_to (BraseroFileNode *node,
 
 	/* NOTE: here stats about the tree can change if the parent has a depth
 	 * > 6 and if previous didn't. Other stats remains unmodified. */
-	stats = brasero_file_node_get_tree_stats (parent, &depth);
-	if (!depth > 6) {
-		stats->num_deep ++;
-		node->is_deep = TRUE;
+	stats = brasero_file_node_get_tree_stats (node->parent, &depth);
+	if (node->is_file) {
+		if (depth < 6)
+			return;
 	}
+	else if (depth < 5)
+		return;
+
+	stats->num_deep ++;
+	node->is_deep = TRUE;
 }
 
 static void
@@ -1018,9 +1042,9 @@ brasero_file_node_destroy_with_children (BraseroFileNode *node,
 
 	/* update all statistics on tree if any */
 	if (stats) {
-		/* check if that's a 2 Gio file */
-		if (node->is_2Gio)
-			stats->num_2Gio --;
+		/* check if that's a 2 GiB file */
+		if (node->is_2GiB)
+			stats->num_2GiB --;
 
 		/* check if that's a deep directory file */
 		if (node->is_deep)
