@@ -1,14 +1,12 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * brasero
- * Copyright (C) Philippe Rouquier 2008 <bonfire-app@wanadoo.fr>
+ * Copyright (C) Philippe Rouquier 2005-2008 <bonfire-app@wanadoo.fr>
  * 
- * brasero is free software.
- * 
- * You may redistribute it and/or modify it under the terms of the
- * GNU General Public License, as published by the Free Software
- * Foundation; either version 2 of the License, or (at your option)
- * any later version.
+ *  Brasero is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  * 
  * brasero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -35,6 +33,7 @@
 
 #include "brasero-jacket-view.h"
 #include "brasero-jacket-buffer.h"
+#include "brasero-utils.h"
 
 typedef struct _BraseroJacketViewPrivate BraseroJacketViewPrivate;
 struct _BraseroJacketViewPrivate
@@ -615,9 +614,15 @@ brasero_jacket_view_focus_in_cb (GtkWidget *view,
 				 GdkEventFocus *event,
 				 BraseroJacketView *self)
 {
+	GtkTextView *text_view = GTK_TEXT_VIEW (view);
 	GtkTextBuffer *buffer;
 
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+	if (text_view->editable) {
+		text_view->need_im_reset = TRUE;
+		gtk_im_context_focus_in (text_view->im_context);
+	}
+
+	buffer = gtk_text_view_get_buffer (text_view);
 	brasero_jacket_buffer_show_default_text (BRASERO_JACKET_BUFFER (buffer), FALSE);
 
 	g_signal_emit (self,
@@ -630,9 +635,15 @@ brasero_jacket_view_focus_out_cb (GtkWidget *view,
 				  GdkEventFocus *event,
 				  BraseroJacketView *self)
 {
+	GtkTextView *text_view = GTK_TEXT_VIEW (view);
 	GtkTextBuffer *buffer;
 
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+	if (text_view->editable) {
+		text_view->need_im_reset = TRUE;
+		gtk_im_context_focus_out (text_view->im_context);
+	}
+
+	buffer = gtk_text_view_get_buffer (text_view);
 	brasero_jacket_buffer_show_default_text (BRASERO_JACKET_BUFFER (buffer), TRUE);
 
 	g_signal_emit (self,
@@ -666,9 +677,8 @@ brasero_jacket_view_scrolled_cb (GtkAdjustment *adj,
 	gtk_adjustment_set_value (adj, 0.0);
 }
 
-static void
-brasero_jacket_view_change_image_activated_cb (GtkMenuItem *item,
-					       BraseroJacketView *self)
+void
+brasero_jacket_view_configure_background (BraseroJacketView *self)
 {
 	BraseroJacketImageStyle image_style;
 	BraseroJacketColorStyle color_style;
@@ -706,6 +716,13 @@ brasero_jacket_view_change_image_activated_cb (GtkMenuItem *item,
 	gtk_widget_destroy (dialog);
 }
 
+static void
+brasero_jacket_view_change_image_activated_cb (GtkMenuItem *item,
+					       BraseroJacketView *self)
+{
+	brasero_jacket_view_configure_background (self);
+}
+
 static void
 brasero_jacket_view_populate_popup_cb (GtkTextView *view,
 				       GtkMenu *menu,
@@ -717,7 +734,7 @@ brasero_jacket_view_populate_popup_cb (GtkTextView *view,
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-	item = gtk_menu_item_new_with_mnemonic (_("Set bac_kground properties"));
+	item = gtk_menu_item_new_with_mnemonic (_("Set Bac_kground Properties"));
 	gtk_widget_show (item);
 	g_signal_connect (item,
 			  "activate",
@@ -869,7 +886,7 @@ brasero_jacket_view_update_edit_image (BraseroJacketView *self)
 				gdk_draw_pixbuf (GDK_DRAWABLE (pixmap),
 						 NULL,
 						 priv->scaled,
-						(gdk_pixbuf_get_width (priv->scaled) - width)/ 2,
+						(gdk_pixbuf_get_width (priv->scaled) - width) / 2,
 						(gdk_pixbuf_get_height (priv->scaled) - height) / 2,
 						 0, 0,
 						 width,
@@ -882,8 +899,8 @@ brasero_jacket_view_update_edit_image (BraseroJacketView *self)
 						 NULL,
 						 priv->scaled,
 						 0, 0,
-						 width - gdk_pixbuf_get_width (priv->scaled) / 2,
-						 height - gdk_pixbuf_get_height (priv->scaled) / 2,
+						 (width - gdk_pixbuf_get_width (priv->scaled)) / 2,
+						 (height - gdk_pixbuf_get_height (priv->scaled)) / 2,
 						 -1,
 						 -1,
 						 GDK_RGB_DITHER_NORMAL,
@@ -1025,7 +1042,7 @@ brasero_jacket_view_update_color (BraseroJacketView *self)
 							       0.0,
 							       width,
 							       0.0);
-		else if (priv->color_style == BRASERO_JACKET_COLOR_VGRADIENT)
+		else /* if (priv->color_style == BRASERO_JACKET_COLOR_VGRADIENT) */
 			pattern = cairo_pattern_create_linear (0.0,
 							       0.0,
 							       0.0,
@@ -1074,17 +1091,11 @@ brasero_jacket_view_set_image (BraseroJacketView *self,
 
 	image = gdk_pixbuf_new_from_file (path, &error);
 	if (error) {
-		GtkWidget *message;
-
-		message = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (self))),
-						  GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
-						  GTK_MESSAGE_ERROR,
-						  GTK_BUTTONS_CLOSE,
-						  _("The image couldn't be loaded:"));
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
-							  error->message);
-		gtk_dialog_run (GTK_DIALOG (message));
-		gtk_widget_destroy (message);
+		brasero_utils_message_dialog (gtk_widget_get_toplevel (GTK_WIDGET (self)),
+					      _("The image could not be loaded."),
+					      error->message,
+					      GTK_MESSAGE_ERROR);
+		g_error_free (error);
 		return priv->image_path;
 	}
 
@@ -1438,9 +1449,6 @@ brasero_jacket_view_container_forall (GtkContainer *container,
 {
 	BraseroJacketViewPrivate *priv;
 
-	if (!include_internals)
-		return;
-
 	priv = BRASERO_JACKET_VIEW_PRIVATE (container);
 	if (priv->edit)
 		callback (priv->edit, callback_data);
@@ -1516,7 +1524,9 @@ brasero_jacket_view_init (BraseroJacketView *object)
 			  G_CALLBACK (brasero_jacket_view_scrolled_cb),
 			  priv->edit);
 
-	gtk_widget_set_scroll_adjustments (priv->edit, GTK_ADJUSTMENT (hadj), GTK_ADJUSTMENT (vadj));
+	gtk_widget_set_scroll_adjustments (priv->edit,
+					   GTK_ADJUSTMENT (hadj),
+					   GTK_ADJUSTMENT (vadj));
 }
 
 static void
