@@ -67,7 +67,6 @@
 #include "brasero-audio-disc.h"
 #include "brasero-video-disc.h"
 #include "brasero-disc-option-dialog.h"
-#include "brasero-burn-dialog.h"
 #include "brasero-utils.h"
 #include "brasero-uri-container.h"
 #include "brasero-layout-object.h"
@@ -578,13 +577,11 @@ static void
 brasero_project_update_project_size (BraseroProject *project,
 				     guint64 sectors)
 {
-	GtkWidget *toplevel;
 	GtkWidget *status;
 	gchar *string;
 	gchar *size;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	status = brasero_app_get_statusbar2 (BRASERO_APP (toplevel));
+	status = brasero_app_get_statusbar2 (brasero_app_get_default ());
 
 	if (!project->priv->status_ctx)
 		project->priv->status_ctx = gtk_statusbar_get_context_id (GTK_STATUSBAR (status),
@@ -765,7 +762,6 @@ brasero_project_check_status (BraseroProject *project,
 	GtkWidget *dialog;
 	gchar *current_task;
 	GtkWidget *progress;
-	GtkWidget *toplevel;
 	gint remaining = -1;
 	BraseroDiscResult result;
 	GtkWidget *current_action;
@@ -778,11 +774,10 @@ brasero_project_check_status (BraseroProject *project,
 	/* we are not ready to create tracks presumably because
 	 * data or audio has not finished to explore a directory
 	 * or get the metadata of a song or a film */
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
 
 	/* This dialog can run as a standalone window when run from nautilus
 	 * to burn burn:// URI contents. */
-	dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     _("Please, wait until the estimation of the project size is completed."),
 				     GTK_BUTTONS_CANCEL,
 				     GTK_MESSAGE_OTHER);
@@ -876,7 +871,7 @@ brasero_project_set_cover_specifics (BraseroProject *self,
 static void
 brasero_project_no_song_dialog (BraseroProject *project)
 {
-	brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (project))),
+	brasero_app_alert (brasero_app_get_default (),
 			   _("Please add songs to the project."),
 			   _("The project is empty"),
 			   GTK_MESSAGE_WARNING);
@@ -885,7 +880,7 @@ brasero_project_no_song_dialog (BraseroProject *project)
 static void
 brasero_project_no_file_dialog (BraseroProject *project)
 {
-	brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (project))),
+	brasero_app_alert (brasero_app_get_default (),
 			   _("Please add files to the project."),
 			   _("The project is empty"),
 			   GTK_MESSAGE_WARNING);
@@ -896,7 +891,6 @@ brasero_project_burn (BraseroProject *project)
 {
 	BraseroBurnSession *session;
 	BraseroDiscResult result;
-	GtkWidget *toplevel;
 	GtkWidget *dialog;
 	gboolean success;
 
@@ -929,15 +923,13 @@ brasero_project_burn (BraseroProject *project)
 	brasero_disc_option_dialog_set_disc (BRASERO_DISC_OPTION_DIALOG (dialog),
 					     project->priv->current);
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
-	gtk_widget_show (dialog);
+	brasero_app_set_toplevel (brasero_app_get_default (), GTK_WINDOW (dialog));
 
 	result = gtk_dialog_run (GTK_DIALOG (dialog));
-	if (result != GTK_RESPONSE_OK)
+	if (result != GTK_RESPONSE_OK) {
+		gtk_widget_destroy (dialog);
 		goto end;
+	}
 
 	session = brasero_disc_option_dialog_get_session (BRASERO_DISC_OPTION_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
@@ -957,24 +949,13 @@ brasero_project_burn (BraseroProject *project)
 	}
 
 	/* now setup the burn dialog */
-	dialog = brasero_burn_dialog_new ();
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-
-	gtk_widget_hide (toplevel);
-	gtk_widget_show (dialog);
-
-	success = brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
-					   session);
-	g_object_unref (session);
+	success = brasero_app_burn (brasero_app_get_default (), session);
 
     	project->priv->burnt = success;
 
 end:
 
 	project->priv->is_burning = 0;
-	gtk_widget_destroy (dialog);
-	gtk_widget_show (toplevel);
 }
 
 /********************************     ******************************************/
@@ -1106,16 +1087,13 @@ gboolean
 brasero_project_confirm_switch (BraseroProject *project)
 {
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	GtkResponseType answer;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-
 	if (project->priv->project) {
 		if (!project->priv->modified)
 			return TRUE;
 
-		dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+		dialog = brasero_app_dialog (brasero_app_get_default (),
 					     _("Do you really want to create a new project and discard the changes to current one?"),
 					     GTK_BUTTONS_CANCEL,
 					     GTK_MESSAGE_WARNING);
@@ -1130,8 +1108,7 @@ brasero_project_confirm_switch (BraseroProject *project)
 		if (project->priv->empty)
 			return TRUE;
 
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-		dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+		dialog = brasero_app_dialog (brasero_app_get_default (),
 					     _("Do you really want to create a new project and discard the current one?"),
 					     GTK_BUTTONS_CANCEL,
 					     GTK_MESSAGE_WARNING);
@@ -1159,7 +1136,6 @@ brasero_project_set_none (BraseroProject *project)
 {
 	GtkAction *action;
 	GtkWidget *status;
-	GtkWidget *toplevel;
 
 	if (project->priv->project) {
 		g_free (project->priv->project);
@@ -1197,8 +1173,7 @@ brasero_project_set_none (BraseroProject *project)
 		gtk_ui_manager_remove_ui (project->priv->manager,
 					  project->priv->merge_id);
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	status = brasero_app_get_statusbar2 (BRASERO_APP (toplevel));
+	status = brasero_app_get_statusbar2 (brasero_app_get_default ());
 
 	if (project->priv->status_ctx)
 		gtk_statusbar_pop (GTK_STATUSBAR (status), project->priv->status_ctx);
@@ -1511,11 +1486,9 @@ brasero_project_empty_cb (GtkAction *action, BraseroProject *project)
 {
 	if (!project->priv->empty) {
 		GtkWidget *dialog;
-		GtkWidget *toplevel;
 		GtkResponseType answer;
 
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-		dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+		dialog = brasero_app_dialog (brasero_app_get_default (),
 					      _("Do you really want to empty the current project?"),
 					     GTK_BUTTONS_CANCEL,
 					     GTK_MESSAGE_WARNING);
@@ -1647,8 +1620,7 @@ brasero_project_set_uri (BraseroProject *project,
 	uri = uri ? uri : project->priv->project;
 
 	/* add it to recent manager */
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	if (brasero_app_is_running (BRASERO_APP (toplevel)))
+	if (brasero_app_is_running (brasero_app_get_default ()))
 		brasero_project_add_to_recents (project, uri, TRUE);
 
 	/* update the name of the main window */
@@ -1657,14 +1629,16 @@ brasero_project_set_uri (BraseroProject *project,
 		title = g_strdup_printf (_("Brasero - %s (Data Disc)"), name);
 	else if (type == BRASERO_PROJECT_TYPE_AUDIO)
 		title = g_strdup_printf (_("Brasero - %s (Audio Disc)"), name);
-	else if (type == BRASERO_PROJECT_TYPE_AUDIO)
+	else if (type == BRASERO_PROJECT_TYPE_VIDEO)
 		title = g_strdup_printf (_("Brasero - %s (Video Disc)"), name);
 	else
 		title = NULL;
  
 	g_free (name);
 
-	gtk_window_set_title (GTK_WINDOW (toplevel), title);
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
+	if (toplevel)
+		gtk_window_set_title (GTK_WINDOW (toplevel), title);
 	g_free (title);
 
 	/* update the menus */
@@ -1677,7 +1651,7 @@ static void
 brasero_project_invalid_project_dialog (BraseroProject *project,
 					const char *reason)
 {
-	brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (project))),
+	brasero_app_alert (brasero_app_get_default (),
 			   _("Error while loading the project."),
 			   reason,
 			   GTK_MESSAGE_ERROR);
@@ -2338,7 +2312,7 @@ brasero_project_not_saved_dialog (BraseroProject *project)
 	xmlError *error;
 
 	error = xmlGetLastError ();
-	brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (project))),
+	brasero_app_alert (brasero_app_get_default (),
 			   _("Your project has not been saved."),
 			   error? error->message:_("An unknown error occured"),
 			   GTK_MESSAGE_ERROR);
@@ -2350,11 +2324,9 @@ brasero_project_save_project_dialog (BraseroProject *project,
 				     gboolean show_cancel)
 {
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	GtkResponseType result;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     _("Save the changes of current project before closing?"),
 				     GTK_BUTTONS_NONE,
 				     GTK_MESSAGE_WARNING);
@@ -3081,16 +3053,27 @@ brasero_project_save_project_as (BraseroProject *project)
 gboolean
 brasero_project_save_session (BraseroProject *project,
 			      const gchar *uri,
+			      gchar **saved_uri,
 			      gboolean show_cancel)
 {
     	BraseroDiscTrack track;
 
+	if (!project->priv->current) {
+		if (saved_uri)
+			*saved_uri = NULL;
+
+		return FALSE;
+	}
+
 	if (project->priv->project) {
 		GtkResponseType answer;
 
 		if (!project->priv->modified) {
 			/* there is a saved project but unmodified.
 			 * No need to ask anything */
+			if (saved_uri)
+				*saved_uri = g_strdup (project->priv->project);
+
 			return FALSE;
 		}
 
@@ -3099,24 +3082,31 @@ brasero_project_save_session (BraseroProject *project,
 		if (answer == GTK_RESPONSE_CANCEL)
 			return TRUE;
 
-		if (answer != GTK_RESPONSE_YES)
+		if (answer != GTK_RESPONSE_YES) {
+			if (saved_uri)
+				*saved_uri = NULL;
+
 			return FALSE;
+		}
 
-		brasero_project_save_project_real (project, NULL, BRASERO_PROJECT_SAVE_XML);
+		if (!brasero_project_save_project_real (project, NULL, BRASERO_PROJECT_SAVE_XML))
+			return TRUE;
+
+		if (saved_uri)
+			*saved_uri = g_strdup (project->priv->project);
 
-		/* return FALSE since this is not a tmp project */
 		return FALSE;
 	}
 
 	if (project->priv->empty) {
 		/* the project is empty anyway. No need to ask anything.
 		 * return FALSE since this is not a tmp project */
+		if (saved_uri)
+			*saved_uri = NULL;
+
 		return FALSE;
 	}
 
-    	if (!project->priv->current)
-		return FALSE;
-
     	if (project->priv->burnt) {
 		GtkResponseType answer;
 
@@ -3126,28 +3116,42 @@ brasero_project_save_session (BraseroProject *project,
 		if (answer == GTK_RESPONSE_CANCEL)
 			return TRUE;
 
-		if (answer != GTK_RESPONSE_YES)
+		if (answer != GTK_RESPONSE_YES) {
+			if (saved_uri)
+				*saved_uri = NULL;
+
 			return FALSE;
+		}
 
-		brasero_project_save_project_as (project);
+		if (!brasero_project_save_project_as (project))
+			return TRUE;
+
+		if (saved_uri)
+			*saved_uri = g_strdup (project->priv->project);
 
-		/* return FALSE since this is not a tmp project */
 		return FALSE;
 	}
 
-    	if (!uri)
+    	if (!uri) {
+		if (saved_uri)
+			*saved_uri = NULL;
+
 		return FALSE;
+	}
 
     	bzero (&track, sizeof (track));
-	if (brasero_disc_get_track (project->priv->current, &track) == BRASERO_DISC_OK)
-		brasero_project_save_project_xml (project,
-						  uri,
-						  &track,
-						  FALSE);
+	if (brasero_disc_get_track (project->priv->current, &track) == BRASERO_DISC_OK) {
+		if (!brasero_project_save_project_xml (project,
+						       uri,
+						       &track,
+						       FALSE))
+			return TRUE;
+	}
 
 	brasero_track_clear (&track);
 
-	/* let the application close itself anyway. It wasn't asked by the user
-	 * and it may get into some critical shutdown */
+	if (saved_uri)
+		*saved_uri = g_strdup (uri);
+
     	return FALSE;
 }
