@@ -7,7 +7,8 @@
  ****************************************************************************/
 
 /*
- * Brasero is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -25,8 +26,8 @@
 #include <glib.h>
 
 #include "burn-basics.h"
-#include "burn-drive.h"
-#include "burn-medium.h"
+#include "brasero-drive.h"
+#include "brasero-medium.h"
 #include "burn-image-format.h"
 
 #ifndef _BURN_TRACK_H
