@@ -43,7 +43,7 @@
 #include "burn-job.h"
 #include "burn-plugin.h"
 #include "burn-volume.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 
 BRASERO_PLUGIN_BOILERPLATE (BraseroReadcd, brasero_readcd, BRASERO_TYPE_PROCESS, BraseroProcess);
 static GObjectClass *parent_class = NULL;
@@ -408,7 +408,7 @@ brasero_readcd_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "readcd",
-			       _("Use readcd to image CDs and DVDs"),
+			       _("Use readcd to create disc images"),
 			       "Philippe Rouquier",
 			       0);
 
