@@ -49,7 +49,7 @@
 #include "burn-job.h"
 #include "burn-checksum-image.h"
 #include "burn-volume.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 
 BRASERO_PLUGIN_BOILERPLATE (BraseroChecksumImage, brasero_checksum_image, BRASERO_TYPE_JOB, BraseroJob);
 
@@ -63,6 +63,8 @@ struct _BraseroChecksumImagePrivate {
 
 	/* this is for the thread and the end of it */
 	GThread *thread;
+	GMutex *mutex;
+	GCond *cond;
 	gint end_id;
 
 	guint cancel;
@@ -577,7 +579,12 @@ brasero_checksum_image_thread (gpointer data)
 						brasero_checksum_image_destroy);
 	}
 
+	/* End thread */
+	g_mutex_lock (priv->mutex);
 	priv->thread = NULL;
+	g_cond_signal (priv->cond);
+	g_mutex_unlock (priv->mutex);
+
 	g_thread_exit (NULL);
 	return NULL;
 }
@@ -604,10 +611,13 @@ brasero_checksum_image_start (BraseroJob *job,
 
 	/* we start a thread for the exploration of the graft points */
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (job);
+	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_checksum_image_thread,
 					BRASERO_CHECKSUM_IMAGE (job),
 					TRUE,
 					error);
+	g_mutex_unlock (priv->mutex);
+
 	if (!priv->thread)
 		return BRASERO_BURN_ERR;
 
@@ -671,12 +681,14 @@ brasero_checksum_image_stop (BraseroJob *job,
 
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (job);
 
+	g_mutex_lock (priv->mutex);
 	if (priv->thread) {
 		priv->cancel = 1;
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
 		priv->cancel = 0;
 		priv->thread = NULL;
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->end_id) {
 		g_source_remove (priv->end_id);
@@ -693,7 +705,13 @@ brasero_checksum_image_stop (BraseroJob *job,
 
 static void
 brasero_checksum_image_init (BraseroChecksumImage *obj)
-{ }
+{	BraseroChecksumImagePrivate *priv;
+
+	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (obj);
+
+	priv->mutex = g_mutex_new ();
+	priv->cond = g_cond_new ();
+}
 
 static void
 brasero_checksum_image_finalize (GObject *object)
@@ -702,12 +720,14 @@ brasero_checksum_image_finalize (GObject *object)
 	
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (object);
 
+	g_mutex_lock (priv->mutex);
 	if (priv->thread) {
 		priv->cancel = 1;
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
 		priv->cancel = 0;
 		priv->thread = NULL;
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->end_id) {
 		g_source_remove (priv->end_id);
@@ -719,6 +739,16 @@ brasero_checksum_image_finalize (GObject *object)
 		priv->checksum = NULL;
 	}
 
+	if (priv->mutex) {
+		g_mutex_free (priv->mutex);
+		priv->mutex = NULL;
+	}
+
+	if (priv->cond) {
+		g_cond_free (priv->cond);
+		priv->cond = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -746,7 +776,10 @@ brasero_checksum_image_export_caps (BraseroPlugin *plugin, gchar **error)
 	BraseroPluginConfOption *checksum_type;
 
 	brasero_plugin_define (plugin,
-			       "Image checksum",
+			       /* Translators: this is the name of the plugin
+				* which will be translated only when it needs
+				* displaying. */
+			       N_("Image Checksum"),
 			       _("Allows to check data integrity on disc after it is burnt"),
 			       "Philippe Rouquier",
 			       0);
